@@ -1,7 +1,7 @@
 
-#  Copyright (c) 1996 Steffen Beyer. All rights reserved.
-#  This program is free software; you can redistribute it and/or
-#  modify it under the same terms as Perl itself.
+#  Copyright (c) 1995, 1996, 1997 by Steffen Beyer. All rights reserved.
+#  This program is free software; you can redistribute it and/or modify
+#  it under the same terms as Perl itself.
 
 package Date::DateCalc;
 
@@ -12,14 +12,18 @@ require DynaLoader;
 
 @EXPORT = qw();
 
-@EXPORT_OK = qw( leap compress uncompress check_compressed compressed_to_short check_date calc_days day_of_week dates_difference calc_new_date date_time_difference calc_new_date_time date_to_short date_to_string week_number first_in_week weeks_in_year day_name_tab month_name_tab decode_day decode_month decode_date days_in_month );
+@EXPORT_OK = qw( leap check_date compress uncompress check_compressed
+compressed_to_short calc_days day_of_week dates_difference calc_new_date
+date_time_difference calc_new_date_time date_to_short date_to_string
+week_number first_in_week weeks_in_year day_name_tab month_name_tab
+decode_day decode_month decode_date days_in_month );
 
 %EXPORT_TAGS = (all => [@EXPORT_OK]);
 
 # "Version" is available but not exported!
 # Call with "Date::DateCalc::Version()"!
 
-$VERSION = '2.3';
+$VERSION = '3.0';
 
 bootstrap Date::DateCalc $VERSION;
 
@@ -29,7 +33,7 @@ __END__
 
 =head1 NAME
 
-Date::DateCalc - Date Calculations
+Date::DateCalc - Gregorian Calendar Date Calculations
 
 in compliance with ISO/R 2015-1971 and DIN 1355 standards
 
@@ -37,17 +41,18 @@ in compliance with ISO/R 2015-1971 and DIN 1355 standards
 
 C<use Date::DateCalc;>
 
-(in which case you must fully qualify every function with the
-name of this module, i.e. C<$flag = Date::DateCalc::leap($year)>)
+(in which case you must fully qualify every function with the name
+of this module, for example C<$flag = Date::DateCalc::leap($year)>)
 
 or
 
 C<use Date::DateCalc>
-C<qw( leap compress uncompress check_compressed compressed_to_short>
-C<check_date calc_days day_of_week dates_difference calc_new_date>
-C<date_time_difference calc_new_date_time date_to_short date_to_string>
-C<week_number first_in_week weeks_in_year day_name_tab month_name_tab>
-C<decode_day decode_month decode_date days_in_month );>
+C<qw( leap check_date compress uncompress check_compressed>
+C<compressed_to_short calc_days day_of_week dates_difference>
+C<calc_new_date date_time_difference calc_new_date_time>
+C<date_to_short date_to_string week_number first_in_week>
+C<weeks_in_year day_name_tab month_name_tab decode_day>
+C<decode_month decode_date days_in_month );>
 
 (or only portions thereof, whatever you need)
 
@@ -55,7 +60,7 @@ or
 
 C<use DateCalc qw(:all);>
 
-(which imports everything)
+(which imports everything).
 
 =head1 DESCRIPTION
 
@@ -77,7 +82,7 @@ depending on the month and the year).
 
 Hint: The functions that support abbreviated year numbers are
 the functions whose names contain the word "compress" and the
-function "decode_date".
+function "decode_date()".
 
 =head2   ====================
 
@@ -93,6 +98,23 @@ No check is made if the year "$year" is in the valid range.
 For years less than 1, the result is probably meaningless (it IS
 almost meaningless, anyway, for years before 1582).
 
+=head2   ==================================
+
+=head2 C<$flag = check_date($year,$mm,$dd);>
+
+=head2   ==================================
+
+This function returns a boolean value which is "true" (1) if the
+three numbers "$year", "$mm" and "$dd" represent a valid date,
+and "false" (0) otherwise.
+
+When determining validity, leap years are taken into account,
+i.e., the 29th of february is rejected in non-leap years.
+
+Year numbers must be greater than zero (negative values will be
+interpreted as large positive numbers due to their internal 2's
+complement binary representation). A year number of zero is invalid.
+
 =head2   ==============================
 
 =head2 C<$date = compress($yy,$mm,$dd);>
@@ -111,11 +133,17 @@ Through this encoding scheme, it is possible to COMPARE ENCODED
 DATES for equality and ORDER (less than/greater than) WITHOUT
 any previous DECODING!!
 
-However, this function can only handle dates within one century.
+Note however that contiguous dates DO NOT NECESSARILY have
+contiguous compressed representations!
 
-This century can be biased at will by choosing a base century
-and year. In this module, the base century is set to 1900 and
-the base year to 70. (Standard on UNIX systems)
+I.e., incrementing the compressed representation of a date may or
+MAY NOT yield a valid new date!
+
+Note also that this function can only handle dates within one century.
+
+This century can be biased at will by choosing a base century and year
+(also called an "epoch"). In this module, the base century is set to
+1900 and the base year to 70 (standard on UNIX systems).
 
 This allows the function to handle dates from 1970 up to 2069.
 
@@ -137,7 +165,7 @@ If no valid date is specified, zero is returned.
 
 =head2   ======================================
 
-This function decodes dates that were encoded by "compress".
+This function decodes dates that were encoded by "compress()".
 It returns the century, year, month and day of the date encoded
 in "$date" in the variables "$cc", "$yy", "$mm" and "$dd",
 respectively.
@@ -145,9 +173,8 @@ respectively.
 The expression "$cc + $yy" yields the complete year number (for
 example, 1900 + 95 = 1995).
 
-If "$date" is zero, all return values are zero as well.
-
-Apart from this, no other checks are performed by this function.
+If "$date" is zero or does not contain the compressed representation
+of a valid date, an empty list is returned.
 
 =head2   ================================
 
@@ -170,7 +197,7 @@ i.e., the 29th of february is rejected in non-leap years.
 This function converts the encoded date in "$date" to a string
 of the format "dd-mmm-yy", which is returned.
 
-("mmm" is the 3-letter abbreviation (in english) of the month)
+("mmm" is the 3-letter abbreviation (in English) of the month's name.)
 
 If the date in "$date" is invalid, the string "<no date>" is
 returned.
@@ -178,23 +205,6 @@ returned.
 Note that the string which is returned by this function is
 always exactly 9 characters long.
 
-=head2   ==================================
-
-=head2 C<$flag = check_date($year,$mm,$dd);>
-
-=head2   ==================================
-
-This function returns a boolean value which is "true" (1) if the
-three numbers "$year", "$mm" and "$dd" represent a valid date,
-and "false" (0) otherwise.
-
-When determining validity, leap years are taken into account,
-i.e., the 29th of february is rejected in non-leap years.
-
-Year numbers must be greater than zero (negative values will be
-interpreted as large positive numbers due to their internal 2's
-complement representation). A year number of zero is invalid.
-
 =head2   =================================
 
 =head2 C<$days = calc_days($year,$mm,$dd);>
@@ -202,16 +212,31 @@ complement representation). A year number of zero is invalid.
 =head2   =================================
 
 This function returns the (theoretical) number of days between
-the first of january of the year one and the given date.
+the first of january of the year one and the given date *plus one*.
+ 
+I.e., the value returned for the first of january of the year one
+is 1, the value returned for the second of january of the year one
+is 2, and so on.
 
-The function doesn't take into account the change from the
-Julian to the Gregorian calendar used today in 1582.
+This is because there is no year zero; the christian calendar starts
+with the year one. Consequently, there is also no day zero; the calendar
+starts with the first day, i.e., day one.
 
-It is needed to calculate the difference in days between two
-dates and the day of week.
+The function doesn't take into account the change from the Julian to
+the Gregorian calendar (used today) in 1582 (or later, for some countries),
+it simply extrapolates the gregorian calendar backwards.
+
+This function is used internally to calculate the difference in days
+between two dates and to calculate the day of week.
+
+Use this function to compare dates for "less than" and "greater than",
+or to compare dates for equality more easily.
 
 Zero is returned if no valid date is specified.
 
+(This is another reason why "C<calc_days(1,1,1)>" is equal to one and
+not to zero!)
+
 =head2   ======================================
 
 =head2 C<$weekday = day_of_week($year,$mm,$dd);>
@@ -249,9 +274,13 @@ you normally specify the two dates in chronological order.
 If date 1 is later than date 2, the result will be negative,
 which allows you to use this function to compare dates.
 
-If one of the two dates is invalid, the result will degrade to
-the value of the function "calc_days" for the other date. If
-both dates are invalid, the result is zero.
+If one of the two dates is invalid, the result will degrade
+to the value of the function "calc_days()" for the other date
+(possibly negative). If both dates are invalid, the result is
+zero.
+
+It is the user's responsibility to make sure that both dates
+are valid (use "check_date()" for this)!
 
 =head2   =======================================================
 
@@ -264,9 +293,12 @@ this function which is "$offset" days away from the original
 date. "$offset" may be positive (for a date later than the
 original date) or negative (for a date earlier than the given date).
 
-If the date cannot be calculated (for instance, if the given
-date is invalid or the new date would be before the year one),
-only zeros are returned.
+If the given date is invalid or the new date cannot be calculated
+(for instance, if the new date would be before the year one),
+an empty list is returned.
+
+To calculate a new date with a year, month and day offset, see the
+function "year_month_day_offset()" in the "Date::DateCalcLib" module.
 
 =head2   ===========================================
 
@@ -283,12 +315,10 @@ you normally specify the two dates in chronological order.
 If date 1 is later than date 2, the result will be negative
 in every of the four return values, which allows you to use
 this function to compare dates and to feed its output into
-the function explained next in this text, "calc_new_date_time".
+the function explained next in this text, "calc_new_date_time()".
 
-If one of the two date/time pairs is invalid, the result will
-degrade to the value of the other date/time argument, converted
-to days, hours, minutes and seconds. If both date/time pairs are
-invalid, the result is zero in every return value.
+If one (or both) of the two date/time pairs is invalid, an empty
+list is returned.
 
 A date/time pair is invalid either when the date is invalid or
 when the values for hour, minute and second are outside the range
@@ -312,8 +342,8 @@ add, for instance, 9 hours and subtract 5 minutes at the same time.
 If the new date and time cannot be calculated (for instance, if
 the given date is invalid or the new date would be before the year
 one, or the values for hour, minute and second are outside the
-range of 0..23, 0..59 and 0..59, respectively), only zeros are
-returned in all return values.
+range of 0..23, 0..59 and 0..59, respectively), an empty list is
+returned.
 
 =head2   ========================================
 
@@ -325,7 +355,7 @@ This function converts the given date to a string of the format
 "www dd-mmm-yyyy", which is returned.
 
 "www" is a (3-letter) abbreviation of the day of week, and "mmm"
-is a (3-letter) abbreviation of the month (both in english).
+is a (3-letter) abbreviation of the month (both in English).
 
 If the given date is invalid, the string "<no date>" is returned.
 
@@ -339,7 +369,7 @@ This function converts the given date to a string of the format
 "wwwwwwwww, dd mmmmmmmmm yyyy", which is returned.
 
 "wwwwwwwww" is the day of week and "mmmmmmmmm" the name of the
-month (both in english).
+month (both in English).
 
 If the given date is invalid, the string "<no date>" is returned.
 
@@ -355,6 +385,8 @@ given date lies.
 This can occasionally be the last week of the previous year
 or the first week of the next year.
 
+If the given date is invalid, an empty list is returned.
+
 =head2   =============================================
 
 =head2 C<($year,$mm,$dd) = first_in_week($week,$year);>
@@ -365,27 +397,32 @@ This function calculates the date of the first day (the Monday)
 of the given week in the given year.
 
 The return value "$year" is adjusted accordingly if the first
-day of the given week lies in the previous or next year (also
-if the given week number is greater than the number of weeks in
-the given year!).
+day of the given week lies in the previous year.
 
-If the date cannot be calculated (for instance, if the calculated
-date would be before the year one), only zeros are returned.
+If the week number is invalid (less than one or greater than the
+number of weeks of the given year, as returned by the function
+"weeks_in_year()"), or if the year is invalid or the date cannot
+be calculated (for example, if the calculated date would be before
+the year one), an empty list is returned.
 
 With help of the expression
 
-	($year,$mm,$dd) = first_in_week(week_number($year,$mm,$dd));
+    ($year,$mm,$dd) = first_in_week(week_number($year,$mm,$dd));
 
 it is possible to easily calculate the date of the Monday belonging
 to the week in which the given date lies.
 
+(However, a fatal Perl error will occur if the given date is invalid!)
+
 Alternatively, the expression
 
-	($year,$mm,$dd) =
-	calc_new_date($year,$mm,$dd,-day_of_week($year,$mm,$dd)+1);
+    ($year,$mm,$dd) =
+    calc_new_date($year,$mm,$dd,-day_of_week($year,$mm,$dd)+1);
 
 can be used to achieve the same effect.
 
+(An empty list is returned if the given date is invalid.)
+
 =head2   ==============================
 
 =head2 C<$weeks = weeks_in_year($year);>
@@ -408,7 +445,7 @@ For years less than 1, the result is probably meaningless.
 This function accesses the internal table of the days of week.
 
 It returns the corresponding string for each numeric value of a
-day of week (as returned by the function "day_of_week").
+day of week (as returned by the function "day_of_week()").
 
 The value of "$weekday" is taken modulo 8 (!) internally to prevent
 out-of-range access to the internal array.
@@ -460,16 +497,16 @@ The strings which are returned are the following:
 
 =head2   ===============================
 
-This function provides the inverse of the function "day_name_tab".
+This function provides the inverse of the function "day_name_tab()".
 
-Whereas "day_name_tab" takes a number as its argument and returns
-a string, "decode_day" takes a string (of any length) and tries
-to match it with the table of the names of days (Monday, Tuesday,
+Whereas "day_name_tab()" takes a number as its argument and returns
+a string, "decode_day()" takes a string (of any length) and tries
+to match it with the table of the names of days ("Monday", "Tuesday",
 and so on) and returns the corresponding number (1..7).
 
 Only the first 3 characters are checked (in case-insensitive
 manner) for a unique match. If it uniquely identifies the day,
-one or two characters are sufficient:
+you may also provide only one or two characters:
 
     Name of the day:     Uniquely identified by:     Value returned:
 
@@ -485,10 +522,9 @@ If there is no match, zero is returned.
 
 This function is roughly equivalent to an associative array:
 
-	%day_tab = ( 'Mon' => 1, 'Tue' => 2, 'Wed' => 3, 'Thu' => 4,
-	             'Fri' => 5, 'Sat' => 6, 'Sun' => 7);
-
-	$weekday = $day_tab{$buffer};
+    %day_tab = ( 'Mon' => 1, 'Tue' => 2, 'Wed' => 3, 'Thu' => 4,
+                 'Fri' => 5, 'Sat' => 6, 'Sun' => 7);
+    $weekday = $day_tab{$buffer};
 
 except for the capability of recognizing abbreviations and
 to be case-independent.
@@ -499,16 +535,16 @@ to be case-independent.
 
 =head2   ===============================
 
-This function provides the inverse of the function "month_name_tab".
+This function provides the inverse of the function "month_name_tab()".
 
 Whereas "month_name_tab" takes a number as its argument and returns
-a string, "decode_month" takes a string (of any length) and tries
-to match it with the table of the names of months (January, February,
+a string, "decode_month" takes a string (of any length) and tries to
+match it with the table of the names of months ("January", "February",
 and so on) and returns the corresponding number (1..12).
 
 Only the first 3 characters are checked (in case-insensitive
 manner) for a unique match. If it uniquely identifies the month,
-one or two characters are sufficient:
+you may also provide only one or two characters:
 
     Name of the month:     Uniquely identified by:     Value returned:
 
@@ -529,11 +565,10 @@ If there is no match, zero is returned.
 
 This function is roughly equivalent to an associative array:
 
-	%month_tab = ( 'Jan' => 1, 'Feb' => 2, 'Mar' => 3, 'Apr' => 4,
-	               'May' => 5, 'Jun' => 6, 'Jul' => 7, 'Aug' => 8,
-	               'Sep' => 9, 'Oct' => 10, 'Nov' => 11, 'Dec' => 12);
-
-	$month = $month_tab{$buffer};
+    %month_tab = ( 'Jan' => 1, 'Feb' => 2, 'Mar' => 3, 'Apr' => 4,
+                   'May' => 5, 'Jun' => 6, 'Jul' => 7, 'Aug' => 8,
+                   'Sep' => 9, 'Oct' => 10, 'Nov' => 11, 'Dec' => 12);
+    $month = $month_tab{$buffer};
 
 except for the capability of recognizing abbreviations and
 to be case-independent.
@@ -544,13 +579,16 @@ to be case-independent.
 
 =head2   =======================================
 
-With help of this function, it is possible to recognize
-dates in almost any format, provided the date is given
-as "day - month - year".
+Using this function, it is possible to parse dates in almost
+any format, provided the date is given as "day - month - year".
+
+(To decode dates in U.S. american format, i.e., dates given
+as "month - day - year", see the function "decode_date_us()"
+in the "Date::DateCalcLib" module.)
 
 The day and the year must be given as numbers, the month may be
-specified either by number or an abbreviation (up to 3 characters
-long) of the month's name (case is ignored).
+specified either by a number or an abbreviation (up to 3 characters
+long) of the month's name in English (case is ignored).
 
 If they uniquely identify the month, one or two letters are
 sufficient (e.g. "s" for september or "ja" for january).
@@ -558,13 +596,12 @@ sufficient (e.g. "s" for september or "ja" for january).
 The year may be abbreviated as well, for instance "95" instead
 of "1995". (Year numbers below 100 are incremented by 1900.)
 
-Any number of non-digits may precede the number of the day and
-follow the number of the year.
+Any number of non-digits (i.e., all characters NOT in [0-9]) may
+precede the number of the day and follow the number of the year.
 
-Between the number of the day and the month, as well as between
-the month and the number of the year, any number of non-alphanumeric
-characters (i.e., all characters not in [A-Za-z0-9])
-may be interspersed.
+Any number of non-alphanumeric characters (i.e., all characters NOT
+in [A-Za-z0-9]) may separate the number of the day and the month and
+the month and the number of the year.
 
 If after removing the preceding and trailing non-digit characters
 the string consists only of digits, it is automatically mapped to
@@ -581,8 +618,7 @@ possible, as follows:
 
 Example:
 
-All the following strings will be recognized as
-"january 3rd 1964":
+All the following strings will be recognized as "January 3rd 1964":
 
 			  3.1.64
 			  3 1 64
@@ -596,8 +632,8 @@ All the following strings will be recognized as
 			   3ja64
 			   3164
 
-If no valid date can be deduced from its input, the function
-returns zeros in all its return values.
+If the function is unable to extract a valid date from its input,
+it returns an empty list.
 
 =head2   =================================
 
@@ -618,32 +654,32 @@ of a month or the last working-day (payday!) of a month.
 Last working-day of the month (legal holidays not taken into
 account):
 
-	$dd = days_in_month($year,$mm);
-	$dw = day_of_week($year,$mm,$dd) - 1;
-	if ($dw > 4)
-	{
-	    ($year,$mm,$dd) = calc_new_date($year,$mm,$dd,4-$dw);
-	}
+    $dd = days_in_month($year,$mm);
+    $dw = day_of_week($year,$mm,$dd) - 1;
+    if ($dw > 4)
+    {
+        ($year,$mm,$dd) = calc_new_date($year,$mm,$dd,4-$dw);
+    }
 
 Last working-day of the month (legal holidays taken into account):
 
-(assuming that the array $holiday[$year][$mm][$dd] = 1; contains
+(assuming that the array C<$holiday[$year][$mm][$dd] = 1;> contains
 all legal holidays)
 
-	$dd = days_in_month($year,$mm);
-	while (1)
-	{
-	    while ($holiday[$year][$mm][$dd])
-	    {
-	        ($year,$mm,$dd) = calc_new_date($year,$mm,$dd,-1);
-	    }
-	    $dw = day_of_week($year,$mm,$dd) - 1;
-	    if ($dw > 4)
-	    {
-	        ($year,$mm,$dd) = calc_new_date($year,$mm,$dd,4-$dw);
-	    }
-	    else { last; }
-	}
+    $dd = days_in_month($year,$mm);
+    while (1)
+    {
+        while ($holiday[$year][$mm][$dd])
+        {
+            ($year,$mm,$dd) = calc_new_date($year,$mm,$dd,-1);
+        }
+        $dw = day_of_week($year,$mm,$dd) - 1;
+        if ($dw > 4)
+        {
+            ($year,$mm,$dd) = calc_new_date($year,$mm,$dd,4-$dw);
+        }
+        else { last; }
+    }
 
 The value of "$mm" is taken modulo 13 (!) internally to prevent
 out-of-range access to the internal array.
@@ -684,81 +720,80 @@ from other packages.
 
 =head1 EXAMPLE
 
-	#!perl -w
-	
-	use strict;
-	no strict "vars";
-	
-	use Date::DateCalc qw(:all);
-	
-	print "\n";
-	
-	$ok = 0;
-	while (! $ok)
-	{
-	    print "Please enter the date of your birthday (day-month-year): ";
-	    $date = <STDIN>;
-	    print "\n";
-	    ($yy1,$mm1,$dd1) = decode_date($date);
-	    if ($yy1)
-	    {
-	        $datestr = date_to_short($yy1,$mm1,$dd1);
-	        print "Your date is: $datestr\n";
-	        print "\n";
-	        print "Is that correct? (Yes/No) ";
-	        $response = <STDIN>;
-	        print "\n";
-	        $ok = ($response =~ /^Y/i);
-	    }
-	}
-	print "Your birthday is: $datestr\n";
-	print "\n";
-	
-	$ok = 0;
-	while (! $ok)
-	{
-	    print "Please enter today's date (day-month-year): ";
-	    $date = <STDIN>;
-	    print "\n";
-	    ($yy2,$mm2,$dd2) = decode_date($date);
-	    if ($yy2)
-	    {
-	        $datestr = date_to_short($yy2,$mm2,$dd2);
-	        print "Your date is: $datestr\n";
-	        print "\n";
-	        print "Is that correct? (Yes/No) ";
-	        $response = <STDIN>;
-	        print "\n";
-	        $ok = ($response =~ /^Y/i);
-	    }
-	}
-	print "Today's date is: $datestr\n";
-	print "\n";
-	
-	$days = dates_difference($yy1,$mm1,$dd1,$yy2,$mm2,$dd2);
-	print "You are $days days old.\n";
-	print "\n";
-	
-	__END__
+    #!perl -w
+
+    use strict;
+    no strict "vars";
+
+    use Date::DateCalc qw(decode_date date_to_short dates_difference);
+
+    print "\n";
+
+    $ok = 0;
+    while (! $ok)
+    {
+        print "Please enter the date of your birthday (day-month-year): ";
+        $date = <STDIN>;
+        print "\n";
+        if (($yy1,$mm1,$dd1) = decode_date($date))
+        {
+            $datestr = date_to_short($yy1,$mm1,$dd1);
+            print "Your date is: $datestr\n";
+            print "\n";
+            print "Is that correct? (Yes/No) ";
+            $response = <STDIN>;
+            print "\n";
+            $ok = ($response =~ /^Y/i);
+        }
+    }
+    print "Your birthday is: $datestr\n";
+    print "\n";
+
+    $ok = 0;
+    while (! $ok)
+    {
+        print "Please enter today's date (day-month-year): ";
+        $date = <STDIN>;
+        print "\n";
+        if (($yy2,$mm2,$dd2) = decode_date($date))
+        {
+            $datestr = date_to_short($yy2,$mm2,$dd2);
+            print "Your date is: $datestr\n";
+            print "\n";
+            print "Is that correct? (Yes/No) ";
+            $response = <STDIN>;
+            print "\n";
+            $ok = ($response =~ /^Y/i);
+        }
+    }
+    print "Today's date is: $datestr\n";
+    print "\n";
+
+    $days = dates_difference($yy1,$mm1,$dd1,$yy2,$mm2,$dd2);
+    print "You are $days days old.\n";
+    print "\n";
+
+    __END__
 
 =head1 SEE ALSO
 
-perl(1), perlsub(1), perlmod(1), perlxs(1), perlxstut(1), perlguts(1).
+Date::DateCalcLib(3), perl(1), perlsub(1),
+perlmod(1), perlxs(1), perlxstut(1), perlguts(1).
 
 =head1 VERSION
 
-This man page documents Date::DateCalc, version 2.3.
+This man page documents Date::DateCalc version 3.0.
 
 =head1 AUTHOR
 
-Steffen Beyer <sb@sdm.de> (sd&m GmbH&Co.KG, Munich, Germany)
+Steffen Beyer <sb@sdm.de>
 
 =head1 COPYRIGHT
 
-Copyright (c) 1996 by Steffen Beyer. All rights reserved.
+Copyright (c) 1995, 1996, 1997 by Steffen Beyer. All rights reserved.
 
 =head1 LICENSE AGREEMENT
 
-This package is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+This package is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
